@@ -19,19 +19,19 @@ def ensure_pyterrier_is_loaded():
 
 def get_preconfigured_chatnoir_client(config_directory, features=['TARGET_URI'], verbose=True, num_results=10, retries=25):
     from chatnoir_pyterrier import ChatNoirRetrieve
-    from chatnoir_api import Index as ChatNoirIndex, html_contents
+    from chatnoir_api import Index as ChatNoirIndex
     from chatnoir_pyterrier.feature import Feature
 
     chatnoir_config = json.load(open(config_directory + '/chatnoir-credentials.json'))
 
-    chatnoir = ChatNoirRetrieve(api_key=chatnoir_config['apikey'])
+    chatnoir = ChatNoirRetrieve(api_key=chatnoir_config['apikey'], staging=chatnoir_config.get('staging', False))
     chatnoir.features = [getattr(Feature, i) for i in features]
     chatnoir.verbose = verbose
     chatnoir.num_results = num_results
     chatnoir.retries = retries
     chatnoir.index = getattr(ChatNoirIndex, chatnoir_config['index'])
     
-    print(f'ChatNoir Client will retrieve from index {chatnoir_config["index"]}')
+    print(f'ChatNoir Client will retrieve the top-{chatnoir.num_results} from index {chatnoir_config["index"]} with {chatnoir.retries} retries.')
     
     return chatnoir
 
